@@ -10,14 +10,18 @@ from typing import Any
 
 from .sql_container import SqlContainer
 from .utils.classes.string_convertible import StringConvertible
-from .utils.classes.special_convertion_requier import SpecialConvertionRequier
 from .utils.classes.container_convertible import ContainerConvertible
+from .utils.classes.json_convertion_requier import JsonConvertionRequier
+from .utils.classes.sql_convertion_requier import SqlConvertionRequier
 
 
-class SqlEnum(StringConvertible, SpecialConvertionRequier, ContainerConvertible, UserList):
+class SqlEnum(
+    StringConvertible, JsonConvertionRequier, SqlConvertionRequier, ContainerConvertible, UserList
+):
     """
     SqlEnum class is invented for better experience to enumerate.
     """
+
     def __init__(
         self,
         *statements: Any,
@@ -33,15 +37,11 @@ class SqlEnum(StringConvertible, SpecialConvertionRequier, ContainerConvertible,
     def __as_json__(self) -> list:
         return list(str(x) for x in self)
 
-    def __add__(self, other) -> str:
-        return self.__as_sql__() + str(other)
-
-    def __radd__(self, other) -> str:
-        return str(other) + self.__as_sql__()
-
     def inline(self) -> SqlContainer:
         """Get inline representation"""
-        return SqlContainer(', '.join(str(x) for x in self))
+        container = SqlContainer(', '.join(str(x) for x in self))
+        container.is_multiline_wrap_type = False
+        return container
 
     def multiline(self) -> SqlContainer:
         """Get multiline representation"""
